==> hledger-web-1.14.1-60-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.14.1
id: hledger-web-1.14.1-3zvP4LFKziLFcYfwdHGAxw
key: hledger-web-1.14.1-3zvP4LFKziLFcYfwdHGAxw
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: ad9293e57002c7d15fb704ff856c0759
exposed: True
exposed-modules:
    Hledger.Web Hledger.Web.Application Hledger.Web.Foundation
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Json Hledger.Web.Main
    Hledger.Web.Settings Hledger.Web.Settings.StaticFiles
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-web-1.14.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-web-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.14.1-3zvP4LFKziLFcYfwdHGAxw
depends:
    Decimal-0.5.1-GJuArZ4JqJp25AlNWxM4Gg
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq base-4.12.0.0
    blaze-html-0.9.1.1-F1eLxc08jYH7pUMZdB1tmO
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    clientsession-0.9.1.2-Idgv9hdIoSfJe2cibji5t6
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-5tT7brArM8HFpf8jCW5Sg8
    conduit-extra-1.3.1.1-1GijJTiXD8TCsMw9tkQ4yM containers-0.6.0.1
    data-default-0.7.1.1-FPe7bpD0gIj5b611SgPKJF directory-1.3.3.0
    filepath-1.4.2.1 hjsmin-0.2.0.2-8AgOgpt2pv5LCW54a1PnqL
    hledger-1.14.2-6XTb0Ut7pUrATM0d4srdgX
    hledger-lib-1.14.1-AHYJskcJEAyBD3ORm6nN5e
    http-client-0.6.4-DL9feDrtt2L2TCX1fo1rt6
    http-conduit-2.3.7.1-GOQd9RDxO2teHuku7U48o
    http-types-0.12.3-LIupN3s0vqzJPmAPHPcGbD
    json-0.9.3-GMBm0GlRjL45CY2W2ruX29
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV mtl-2.2.2
    shakespeare-2.0.20-2LpZYdt2yedJT1tZWNorEi template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    wai-3.2.2-FKI9I9MeRyhBwlVDOn737X
    wai-extra-3.0.26-HrUHZAyS1qZLS4gDv7ankX
    wai-handler-launch-3.0.2.4-9UuFBx3gfRJGKnNJPxfmA
    warp-3.2.27-EnnuUbTHmIYOaOhzBXl5W
    yaml-0.11.0.0-5tiUC9jlRkdJe9RddgUA9v
    yesod-1.6.0-5xQbWsCo7NlE1IbPBOHdb
    yesod-core-1.6.14-LAqm4iYGZCw4dtd9dCHf8B
    yesod-form-1.6.4-75s93rZtPtHgcZgoVvGoT
    yesod-static-1.6.0.1-IobMKbYdAseCOZ2vrpf8B2
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.14.1-62-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.14.1
id: hledger-web-1.14.1-8zFyCM26ZTC9kxbG2aFuAC
key: hledger-web-1.14.1-8zFyCM26ZTC9kxbG2aFuAC
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 744d3247f586d6dafac99398adbe5b70
exposed: True
exposed-modules:
    Hledger.Web Hledger.Web.Application Hledger.Web.Foundation
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Json Hledger.Web.Main
    Hledger.Web.Settings Hledger.Web.Settings.StaticFiles
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-web-1.14.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-web-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.14.1-8zFyCM26ZTC9kxbG2aFuAC
depends:
    Decimal-0.5.1-GJuArZ4JqJp25AlNWxM4Gg
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq base-4.12.0.0
    blaze-html-0.9.1.1-F1eLxc08jYH7pUMZdB1tmO
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    clientsession-0.9.1.2-Idgv9hdIoSfJe2cibji5t6
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-Jmotk7FVIoVB29sd5GQrbo
    conduit-extra-1.3.1.1-8DKOTbZemO3LCQI37UomjU containers-0.6.0.1
    data-default-0.7.1.1-FPe7bpD0gIj5b611SgPKJF directory-1.3.3.0
    filepath-1.4.2.1 hjsmin-0.2.0.2-8AgOgpt2pv5LCW54a1PnqL
    hledger-1.14.2-6XTb0Ut7pUrATM0d4srdgX
    hledger-lib-1.14.1-AHYJskcJEAyBD3ORm6nN5e
    http-client-0.6.4-4CFp7jDYU2o30hkMqNDdPn
    http-conduit-2.3.7.1-2HhRciK6eYxIdjqttJNgUe
    http-types-0.12.3-LIupN3s0vqzJPmAPHPcGbD
    json-0.9.3-GMBm0GlRjL45CY2W2ruX29
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV mtl-2.2.2
    shakespeare-2.0.20-2LpZYdt2yedJT1tZWNorEi template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    wai-3.2.2-FKI9I9MeRyhBwlVDOn737X
    wai-extra-3.0.26-AdRFyN9RoX4BX4Xv32BBos
    wai-handler-launch-3.0.2.4-9UaN52xG8QD29AM9e9fUW6
    warp-3.2.27-EZcQrhbgPBiGRLcQ5Hoes6
    yaml-0.11.0.0-61P0eSjBEMM82kzW7c5TWU
    yesod-1.6.0-6kHSmYC2ZpN2NRUjFPENEg
    yesod-core-1.6.14-g1iMJza12m5hFLG3wgvWf
    yesod-form-1.6.4-BN8SfK7oIVI8hlA4q7nEys
    yesod-static-1.6.0.1-1e7Ld8KTSrG8cICgTkBOiZ
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
